<?php

/**
 * This is the model class for table "pc_agent_transactions".
 *
 * The followings are the available columns in table 'pc_agent_transactions':
 * @property integer $pcat_id
 * @property integer $pcat_aid
 * @property integer $pcat_userid
 * @property double $pcat_amount
 * @property string $pcat_code
 * @property string $pcat_expires
 * @property integer $pcat_status
 * @property string $pcat_created_at
 * @property string $pcat_updated_at
 */
class AgentTransactions extends CActiveRecord
{
	public $pcat_user_qr_code;
	public $verifyCode;
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_agent_transactions';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(

			array('verifyCode', 'captcha', 'allowEmpty'=> !CCaptcha::checkRequirements(), 'on'=>'add,withdraw'),
			array('pcat_code,pcat_user_qr_code', 'required', 'on'=>'CodeUpdate'),

			array('pcat_user_qr_code', 'checkqrcode','on'=>'CodeUpdate'),

			array('pcat_aid, pcat_amount', 'required','on'=>'add,withdraw'),
			array('pcat_amount', 'numerical','on'=>'add,withdraw'),
			array('pcat_code', 'length', 'max'=>32),
			array('pcat_id, pcat_aid, pcat_userid,pcat_type, pcat_amount, pcat_code, pcat_expires, pcat_status, pcat_created_at, pcat_updated_at', 'safe', 'on'=>'search,withdraw,add'),
		);
	}

	public function checkqrcode(){

		$model = AgentTransactions::model()->findAll('pcat_id = ? AND pcat_user_qr = ? ',array($this->pcat_id, $this->pcat_user_qr_code));

		if(count($model)>0)
		return true;
		else
		return $this->addError('pcat_user_qr_code', 'Please check once again your customer QR code');

	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'UserRel' => array(self::BELONGS_TO, 'Userdetails', 'pcat_userid'),
			'AgentRel' => array(self::BELONGS_TO, 'Agents', 'pcat_aid'),
		);

	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcat_id' => 'Pcat',
			'pcat_aid' => 'Store Name',
			'pcat_userid' => 'Customer Name',
			'pcat_amount' => 'Amount',
			'pcat_commission' => 'Commission',
			'pcat_code' => 'Transaction ID',
			'pcat_type' => 'Type',
			'pcat_user_qr_code' => 'Customer QR Code',
			'pcat_expires' => 'Expires',
			'pcat_status' => 'Status',
			'pcat_created_at' => 'Created Date',
			'pcat_updated_at' => 'Updated Date',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function agent_transactions_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel','AgentRel');
		$criteria->together = true;
		$criteria->compare('pcat_id',$this->pcat_id);
		$criteria->compare('pcat_aid',$this->pcat_aid);
		$criteria->compare('pcat_userid',$this->pcat_userid);
		$criteria->compare('pcat_user_qr',$this->pcat_user_qr);
		$criteria->compare('pcat_amount',$this->pcat_amount);
		if(isset($_GET['dtype']) && $_GET['dtype'] != ''){

			$criteria->compare('pcat_type',$_GET['dtype']);
		} else
		{
			$criteria->compare('pcat_type',$this->pcat_type);
		}
		$criteria->compare('pcat_code',$this->pcat_code,true);
		$criteria->compare('pcat_expires',$this->pcat_expires,true);
		if(isset($_GET['type']) && $_GET['type'] != ''){

			$criteria->compare('pcat_status',$_GET['type']);
		} else
		{
			$criteria->compare('pcat_status',$this->pcat_status);
		}
		$criteria->compare('pcat_created_at',$this->pcat_created_at,true);
		$criteria->compare('pcat_updated_at',$this->pcat_updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcat_created_at DESC',
                    ),
		));
	}


	public function agent_user_transactions_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel','AgentRel');
		$criteria->together = true;
		$criteria->compare('pcat_id',$this->pcat_id);
		$criteria->compare('pcat_aid',$this->pcat_aid);
		$criteria->compare('pcat_userid',Yii::app()->user->getState('Userid'));
		$criteria->compare('pcat_user_qr',$this->pcat_user_qr);
		if(isset($_GET['dtype']) && $_GET['dtype'] != ''){

			$criteria->compare('pcat_type',$_GET['dtype']);
		} else
		{
			$criteria->compare('pcat_type',$this->pcat_type);
		}
		$criteria->compare('pcat_amount',$this->pcat_amount);
		$criteria->compare('pcat_code',$this->pcat_code,true);
		$criteria->compare('pcat_expires',$this->pcat_expires,true);
		if(isset($_GET['type']) && $_GET['type'] != ''){

			$criteria->compare('pcat_status',$_GET['type']);
		} else
		{
			$criteria->compare('pcat_status',$this->pcat_status);
		}
		$criteria->compare('pcat_created_at',$this->pcat_created_at,true);
		$criteria->compare('pcat_updated_at',$this->pcat_updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcat_created_at DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return AgentTransactions the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->pcat_created_at	= date('Y-m-d H:i:s');
		else
			$this->pcat_updated_at	= date('Y-m-d H:i:s');

		return true;
	}
}
