<?php

/**
 * This is the model class for table "pc_cards".
 *
 * The followings are the available columns in table 'pc_cards':
 * @property integer $pcc_id
 * @property integer $pcc_userid
 * @property string $pcc_cardname
 * @property string $pcc_cardnumber
 * @property integer $pcc_cvv
 * @property integer $pcc_expire_month
 * @property integer $pcc_expire_year
 * @property integer $pcc_status
 * @property integer $pcc_default
 * @property string $created_at
 * @property string $updated_at
 */
class Cards extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */

	public $ccard_number;
	public $camount;

	public function tableName()
	{
		return 'pc_cards';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcc_cardname, pcc_cardnumber, pcc_cvv, pcc_expire_month, pcc_expire_year', 'required','on' => 'addcard'),
			array('camount,ccard_number', 'required','on' => 'deposit'),
			array('pcc_id, pcc_userid, pcc_cvv, pcc_expire_month, pcc_expire_year, pcc_status, pcc_default', 'numerical', 'integerOnly'=>true),
			array('pcc_cardname', 'length', 'max'=>64),
			array('pcc_cardnumber', 'length', 'max'=>32),
			array('pcc_id, pcc_userid, pcc_cardname, pcc_cardnumber, pcc_cvv, pcc_expire_month, pcc_expire_year, pcc_status, pcc_default, created_at, updated_at', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcc_id' => 'Pcc',
			'pcc_userid' => 'Userid',
			'pcc_cardname' => 'Cardname',
			'pcc_cardnumber' => 'Cardnumber',
			'pcc_cvv' => 'Cvv',
			'pcc_expire_month' => 'Expire Month',
			'pcc_expire_year' => 'Expire Year',
			'pcc_status' => 'Status',
			'pcc_default' => 'Default',
			'ccard_number' => 'Select a debit/credit Card',
			'camount' => 'Amount',
			'created_at' => 'Created At',
			'updated_at' => 'Updated At',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcc_id',$this->pcc_id);
		$criteria->compare('pcc_userid',$this->pcc_userid);
		$criteria->compare('pcc_cardname',$this->pcc_cardname,true);
		$criteria->compare('pcc_cardnumber',$this->pcc_cardnumber,true);
		$criteria->compare('pcc_cvv',$this->pcc_cvv);
		$criteria->compare('pcc_expire_month',$this->pcc_expire_month);
		$criteria->compare('pcc_expire_year',$this->pcc_expire_year);
		$criteria->compare('pcc_status',$this->pcc_status);
		$criteria->compare('pcc_default',$this->pcc_default);
		$criteria->compare('created_at',$this->created_at,true);
		$criteria->compare('updated_at',$this->updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcc_id DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Cards the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->created_at	= date('Y-m-d H:i:s');
		else
			$this->updated_at	= date('Y-m-d H:i:s');

		return true;
	}
}
