<?php

/**
 * This is the model class for table "pc_currency".
 *
 * The followings are the available columns in table 'pc_currency':
 * @property integer $pcc_id
 * @property integer $pcc_name
 * @property string $pcc_code
 * @property integer $pcc_status
 */
class Currency extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_currency';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcc_name, pcc_code, pcc_status,pcc_position,pcc_symbol', 'required'),
			array('pcc_status,pcc_position', 'numerical', 'integerOnly'=>true),
			array('pcc_code', 'length', 'max'=>10),
			array('pcc_id, pcc_name, pcc_code, pcc_status', 'safe', 'on'=>'search'),
		);
	}

	public static function listData()
	{
		$listData = CHtml::listData(Currency::model()->findAll(array('condition'=>'pcc_status = 1','order'=>'pcc_name ASC')),'pcc_id','pcc_code');
		return $listData;
	}

	public static function getCurrencyName($id){

		$data = Currency::model()->findByPk($id);
		return $data;
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcc_id' => 'Pcc',
			'pcc_name' => 'Name',
			'pcc_code' => 'Code',
			'pcc_position' => 'Symbol Position',
			'pcc_symbol' => 'Symbol',
			'pcc_status' => 'Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcc_id',$this->pcc_id);
		$criteria->compare('pcc_name',$this->pcc_name);
		$criteria->compare('pcc_code',$this->pcc_code,true);
		$criteria->compare('pcc_status',$this->pcc_status);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcc_id DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Currency the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
