<?php

/**
 * LoginForm class.
 * LoginForm is the data structure for keeping
 * user login form data. It is used by the 'login' action of 'SiteController'.
 */
class RegulatorLogin extends CFormModel
{
	public $regulator_email;
	public $rememberMe;
	public $regulator_password;

	private $_identity;

	public function tableName()
	{
		return 'pc_user';
	}

	public function rules()
	{
		return array(
			// username and password are required
			array('regulator_email,regulator_password', 'required','on'=>'regulatorlogin'),

			array('regulator_email', 'match','pattern'=>'/^([\w-\.]+@([\w-]+\.)+[\w-]{2,4})?$/','message'=>'Invalid Email ID', 'on'=>'regulatorlogin'),
			array('regulator_password', 'authenticate','on'=>'regulatorlogin'),
		);
	}

	/**
	 * Declares attribute labels.
	 */
	public function attributeLabels()
	{
		return array(
			'regulator_email'=>'Email address',
			'regulator_password'=>'Password',
			);
	}

	/**
	 * Authenticates the password.
	 * This is the 'authenticate' validator as declared in rules().
	 */
	public function authenticate($attribute,$params)
	{
		if(!$this->hasErrors())
		{
			$this->_identity=new UserIdentity($this->regulator_email,$this->regulator_password);
			if(!$this->_identity->authenticate())
				$this->addError('regulator_password','Incorrect email or password.');
		}
	}

	/**
	 * Logs in the user using the given email and password in the model.
	 * @return boolean whether login is successful
	 */
	public function login()
	{
		if($this->_identity===null)
		{
			$this->_identity=new UserIdentity($this->regulator_email,$this->regulator_password);
			$this->_identity->authenticate();
		}
		if($this->_identity->errorCode===UserIdentity::ERROR_NONE)
		{
			$duration=$this->rememberMe ? 3600*24*30 : 0; // 30 days
			Yii::app()->user->login($this->_identity,$duration);
			return true;
		}
		else
			return false;
	}
}
