<?php

/**
 * LoginForm class.
 * LoginForm is the data structure for keeping
 * user login form data. It is used by the 'login' action of 'SiteController'.
 */
class UserLogin extends CFormModel
{
	public $user_email;
	public $user_password;
	public $user_country;
	public $re_password;
	public $rememberMe;

	private $_identity;

	public function tableName()
	{
		return 'pc_user';
	}

	public function rules()
	{
		return array(
			// username and password are required
			array('user_email,user_password', 'required','on'=>'login,register'),
			array('user_country', 'required', 'on'=>'register'),
			array('re_password', 'required', 'on'=>'register'),
			array('user_email', 'checkunique', 'on'=>'register'),

			array('user_password', 'passwordStrength', 'on'=>'register'),


			array('user_email', 'match','pattern'=>'/^([\w-\.]+@([\w-]+\.)+[\w-]{2,4})?$/','message'=>'Invalid Email ID', 'on'=>'register,login'),
			
			array('user_password,re_password','length','min'=>6,'message'=>'Password characters should alphanumeric and min(6 digits)','on'=>'register'),

        	array('user_password', 'compare', 'compareAttribute'=>'re_password', 'on'=>'register'),
			// rememberMe needs to be a boolean
			array('rememberMe', 'boolean'),
			// password needs to be authenticated
			array('user_password', 'authenticate','on'=>'login'),
		);
	}

	public function passwordStrength($attribute)
	{
	    $pattern = '/^(?=.*\d(?=.*\d))(?=.*[a-zA-Z](?=.*[a-zA-Z])).{5,}$/';  
	 
	    if(!preg_match($pattern, $this->$attribute))
	      $this->addError($attribute, 'For security reasons, we recommended using alphanumerical characters or symbols in your password.');
	}
	/**
	 * Declares attribute labels.
	 */
	public function attributeLabels()
	{
		return array(
			'user_email'=>'Email address',
			'user_password'=>'Password',
			'user_country'=>'Country',
			're_password'=>'Re-enter password',
		);
	}

	public function checkunique(){

		$data = User::model()->findAll("user_email =? AND user_type= ?",array($this->user_email,2));
		if(count($data) >0)
			$this->addError("user_email",'It seems email already exists. <a href="'.Common::usercreateUrl("login").'">Log In</a>');
	}
	/**
	 * Authenticates the password.
	 * This is the 'authenticate' validator as declared in rules().
	 */
	public function authenticate($attribute,$params)
	{
		if(!$this->hasErrors())
		{
			$this->_identity=new UserIdentity($this->user_email,$this->user_password);
			if(!$this->_identity->authenticate())
				$this->addError('user_password','Incorrect email or password.');
		}
	}

	/**
	 * Logs in the user using the given email and password in the model.
	 * @return boolean whether login is successful
	 */
	public function login()
	{
		if($this->_identity===null)
		{
			$this->_identity=new UserIdentity($this->user_email,$this->user_password);
			$this->_identity->authenticate();
		}
		if($this->_identity->errorCode===UserIdentity::ERROR_NONE)
		{
			$duration=$this->rememberMe ? 3600*24*30 : 0; // 30 days
			Yii::app()->user->login($this->_identity,$duration);
			return true;
		}
		else
			return false;
	}
}
